@@ -6,6 +6,7 @@ import statsmodels.stats.multitest
 import time
 import sys
 import collections
+import functools
 
 hasR = False
 try:
@@ -17,7 +18,7 @@ except Exception as e:
 if hasR:
     from rpy2.robjects import r, DataFrame, globalenv, IntVector, FloatVector, StrVector, packages as rpackages
 
-import base
+from pytransit.analysis import base
 import pytransit
 import pytransit.transit_tools as transit_tools
 import pytransit.tnseq_tools as tnseq_tools
@@ -32,6 +33,7 @@ long_desc = """Perform ZINB analysis"""
 EOL = "\n"
 DEBUG = False
 GENE = None
+SEPARATOR = '\1' # for making names that combine conditions and interactions; try not to use a char a user might have in a condition name
 
 transposons = ["", ""]
 columns = []
@@ -57,8 +59,8 @@ class ZinbMethod(base.MultiConditionMethod):
     @classmethod
     def fromargs(self, rawargs):
         if not hasR:
-            print("Error: R and rpy2 (< 2.9.0) required to run ZINB analysis.")
-            print("After installing R, you can install rpy2 using the command \"pip install 'rpy2<2.9.0'\"")
+            print("Error: R and rpy2 (~= 3.0) required to run ZINB analysis.")
+            print("After installing R, you can install rpy2 using the command \"pip install 'rpy2~=3.0'\"")
             sys.exit(0)
 
         (args, kwargs) = transit_tools.cleanargs(rawargs)
@@ -83,11 +85,11 @@ class ZinbMethod(base.MultiConditionMethod):
         NTerminus = float(kwargs.get("iN", 5.0))
         CTerminus = float(kwargs.get("iC", 5.0))
         condition = kwargs.get("-condition", "Condition")
-        covars = filter(None, kwargs.get("-covars", "").split(","))
-        interactions = filter(None, kwargs.get("-interactions", "").split(","))
-        winz = True if kwargs.has_key("w") else False
-        ignored_conditions = filter(None, kwargs.get("-ignore-conditions", "").split(","))
-        included_conditions = filter(None, kwargs.get("-include-conditions", "").split(","))
+        covars = list(filter(None, kwargs.get("-covars", "").split(",")))
+        interactions = list(filter(None, kwargs.get("-interactions", "").split(",")))
+        winz = True if "w" in kwargs else False
+        ignored_conditions = list(filter(None, kwargs.get("-ignore-conditions", "").split(",")))
+        included_conditions = list(filter(None, kwargs.get("-include-conditions", "").split(",")))
         if len(included_conditions) > 0 and len(ignored_conditions) > 0:
             self.transit_error("Cannot use both include-conditions and ignore-conditions flags")
             print(ZinbMethod.usage_string())
@@ -177,7 +179,7 @@ class ZinbMethod(base.MultiConditionMethod):
         for i, conditionForWig in enumerate(conditions):
             if (len(interactions) > 0):
                 for interaction in interactions:
-                    groupName = conditionForWig + '_' + interaction[i]
+                    groupName = conditionForWig + SEPARATOR + interaction[i] 
                     groupWigIndexMap[groupName].append(i)
             else:
                 groupName = conditionForWig
@@ -227,8 +229,8 @@ class ZinbMethod(base.MultiConditionMethod):
         return [
                 numpy.concatenate(readCountsForRv).astype(int),
                 repeatAndFlatten(conditions),
-                map(repeatAndFlatten, covariates),
-                map(repeatAndFlatten, interactions),
+                list(map(repeatAndFlatten, covariates)),
+                list(map(repeatAndFlatten, interactions)),
                 repeatAndFlatten(NZMeanByRep),
                 repeatAndFlatten(LogZPercByRep)
                ]
@@ -269,7 +271,7 @@ class ZinbMethod(base.MultiConditionMethod):
                     mod = zeroinfl(as.formula(zinbMod1),data=melted,dist="negbin")
                     coeffs = summary(mod)$coefficients
                     # [,1] is col of parms, [,2] is col of stderrs, assume Intercept is always first
-                    #if (coeffs$count[,2][1]>0.5) { status = 'warning: high stderr on Intercept for mod1' }
+                    if (coeffs$count[,2][1]>0.5) { status = 'warning: high stderr on Intercept for mod1' }
                     mod
                   } else {
                     f1 = nbMod1
@@ -326,7 +328,7 @@ class ZinbMethod(base.MultiConditionMethod):
         if (len(unique_counts) < 2):
             return data
         else:
-            n, n_minus_1 = unique_counts[heapq.nlargest(2, xrange(len(unique_counts)), unique_counts.take)]
+            n, n_minus_1 = unique_counts[heapq.nlargest(2, range(len(unique_counts)), unique_counts.take)]
             result = [[ n_minus_1 if count == n else count
                         for count in wig] for wig in data]
         return numpy.array(result)
@@ -373,7 +375,7 @@ class ZinbMethod(base.MultiConditionMethod):
 
         nbMod1 = "cnt~%s" % (comp1a)
         nbMod0 = "cnt~%s" % (comp0a)
-        toRFloatOrStrVec = lambda xs: FloatVector(xs) if self.is_number(xs[0]) else StrVector(xs)
+        toRFloatOrStrVec = lambda xs: FloatVector([float(x) for x in xs]) if self.is_number(xs[0]) else StrVector(xs)
 
         for gene in genes:
             count += 1
@@ -381,7 +383,7 @@ class ZinbMethod(base.MultiConditionMethod):
             ## Single gene case for debugging
             if (GENE):
                 Rv = None
-                if RvSiteindexesMap.has_key(GENE):
+                if GENE in RvSiteindexesMap:
                     Rv = GENE
                 else:
                     for g in genes:
@@ -396,8 +398,10 @@ class ZinbMethod(base.MultiConditionMethod):
                 status.append("TA sites <= 1")
                 pvals.append(1)
             else:
-                norm_data = self.winsorize(map(
-                    lambda wigData: wigData[RvSiteindexesMap[Rv]], data)) if self.winz else map(lambda wigData: wigData[RvSiteindexesMap[Rv]], data)
+                # For winsorization
+                # norm_data = self.winsorize((map(
+                #     lambda wigData: wigData[RvSiteindexesMap[Rv]], data))) if self.winz else list(map(lambda wigData: wigData[RvSiteindexesMap[Rv]], data))
+                norm_data = list(map(lambda wigData: wigData[RvSiteindexesMap[Rv]], data))
                 ([ readCounts,
                    condition,
                    covarsData,
@@ -417,8 +421,8 @@ class ZinbMethod(base.MultiConditionMethod):
                         'logitZperc': FloatVector(logitZPerc)
                         }
                     ## Add columns for covariates and interactions if they exist.
-                    df_args.update(map(lambda (i, c): (c, toRFloatOrStrVec(covarsData[i])), enumerate(self.covars)))
-                    df_args.update(map(lambda (i, c): (c, toRFloatOrStrVec(interactionsData[i])), enumerate(self.interactions)))
+                    df_args.update(list(map(lambda t_ic: (t_ic[1], toRFloatOrStrVec(covarsData[t_ic[0]])), enumerate(self.covars))))
+                    df_args.update(list(map(lambda t_ic: (t_ic[1], toRFloatOrStrVec(interactionsData[t_ic[0]])), enumerate(self.interactions))))
 
                     melted = DataFrame(df_args)
                     # r_args = [IntVector(readCounts), StrVector(condition), melted, map(lambda x: StrVector(x), covars), FloatVector(NZmean), FloatVector(logitZPerc)] + [True]
@@ -498,8 +502,8 @@ class ZinbMethod(base.MultiConditionMethod):
         pvals, qvals, run_status = self.run_zinb(data, genes, NZMeanByRep, LogZPercByRep, RvSiteindexesMap, conditions, covariates, interactions)
 
         def orderStats(x, y):
-            ic1 = x.split("_")
-            ic2 = y.split("_")
+            ic1 = x.split(SEPARATOR)
+            ic2 = y.split(SEPARATOR)
             c1, i1 = (ic1[0], ic1[1]) if len(ic1) > 1 else (ic1[0], None)
             c2, i2 = (ic2[0], ic2[1]) if len(ic2) > 1 else (ic2[0], None)
 
@@ -516,14 +520,15 @@ class ZinbMethod(base.MultiConditionMethod):
                 return (orderingMetadata['interaction'].index(i1) - orderingMetadata['interaction'].index(i2))
             return condDiff
 
-        orderedStatGroupNames = sorted(statGroupNames, orderStats)
+        orderedStatGroupNames = sorted(statGroupNames, key=functools.cmp_to_key(orderStats))
+        headersStatGroupNames = [x.replace(SEPARATOR,'_') for x in orderedStatGroupNames]
 
         self.transit_message("Adding File: %s" % (self.output))
         file = open(self.output,"w")
         head = ("Rv Gene TAs".split() +
-                map(lambda v: "Mean_" + v, orderedStatGroupNames) +
-                map(lambda v: "NZmean_" + v, orderedStatGroupNames) +
-                map(lambda v: "NZperc_" + v, orderedStatGroupNames) +
+                list(map(lambda v: "Mean_" + v, headersStatGroupNames)) +
+                list(map(lambda v: "NZmean_" + v, headersStatGroupNames)) +
+                list(map(lambda v: "NZperc_" + v, headersStatGroupNames)) +
                 "pval padj".split() + ["status"])
 
         file.write("#Console: python %s\n" % " ".join(sys.argv))
