@@ -26,19 +26,6 @@ import threading
 import numpy
 import matplotlib
 
-# Check backends and use the first interactive one
-interactive_backends = [i for i in matplotlib.rcsetup.interactive_bk]
-goodBackend = False
-for backend in interactive_backends:
-    if goodBackend: break
-    try:
-        matplotlib.use(backend,warn=False, force=True)
-        from matplotlib import pyplot as plt
-        goodBackend = True
-    except:
-        goodBackend = False
-
-
 import matplotlib.pyplot as plt
 import multiprocessing as mp
 import math
@@ -266,7 +253,7 @@ class MainFrame ( wx.Frame ):
         self.logoImg = wx.StaticBitmap( self.optionsWindow, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, 0 )
         self.optionsSizer.Add( self.logoImg, 0, wx.ALL|wx.ALIGN_CENTER, 5 )
 
-        self.versionLabel = wx.StaticText( self.optionsWindow, wx.ID_ANY, u"", wx.DefaultPosition, wx.DefaultSize, wx.ALIGN_CENTRE )
+        self.versionLabel = wx.StaticText( self.optionsWindow, wx.ID_ANY, u"", wx.DefaultPosition,(100,25), wx.ALIGN_CENTRE )
         self.versionLabel.Wrap( -1 )
         self.versionLabel.SetFont( wx.Font( 10, 74, 90, 92, False, "Sans" ) )
 
@@ -663,8 +650,8 @@ class TnSeekFrame(MainFrame):
         self.annotation = ""
         self.transposons = ["himar1", "tn5"]
         #import pkgutil
-        #print [x for x in pkgutil.iter_modules(['transit/analysis'])]
-        #print gumbel.Gumbel.__bases__
+        #print([x for x in pkgutil.iter_modules(['transit/analysis'])])
+        #print(gumbel.Gumbel.__bases__)
 
         self.logoImg.SetBitmap(images.transit_logo2.GetImage().ConvertToBitmap())
         self.versionLabel.SetLabel(pytransit.__version__)
@@ -794,7 +781,7 @@ class TnSeekFrame(MainFrame):
                     transit_tools.transit_message("Adding Ctrl File: " + path)
                     self.loadCtrlFile(path)
                 except Exception as e:
-                    print "Error:", str(e)
+                    print("Error:", str(e))
 
             expData = ["cholesterol_H37Rv_rep1.wig", "cholesterol_H37Rv_rep2.wig", "cholesterol_H37Rv_rep3.wig"]
             for dataset in expData:
@@ -803,13 +790,13 @@ class TnSeekFrame(MainFrame):
                     transit_tools.transit_message("Adding Exp File: " + path)
                     self.loadExpFile(path)
                 except Exception as e:
-                    print "Error:", str(e)
+                    print("Error:", str(e))
 
             try:
                 self.annotation = os.path.join(os.path.dirname('/pacific/home/mdejesus/transit/src/transit.py'), "pytransit/genomes/H37Rv.prot_table")
                 transit_tools.transit_message("Annotation File Selected: %s" % self.annotation)
             except Exception as e:
-                print "Error:", str(e)
+                print("Error:", str(e))
 
 #
 
@@ -1193,9 +1180,9 @@ class TnSeekFrame(MainFrame):
                 )
             if dlg.ShowModal() == wx.ID_OK:
                 paths = dlg.GetPaths()
-                print "You chose the following Control file(s):"
+                print("You chose the following Control file(s):")
                 for fullpath in paths:
-                    print "\t%s" % fullpath
+                    print("\t%s" % fullpath)
                     self.loadCtrlFile(fullpath)
             dlg.Destroy()
         except Exception as e:
@@ -1220,14 +1207,14 @@ class TnSeekFrame(MainFrame):
                 )
             if dlg.ShowModal() == wx.ID_OK:
                 paths = dlg.GetPaths()
-                print "You chose the following Experimental file(s):"
+                print("You chose the following Experimental file(s):")
                 for fullpath in paths:
-                    print "\t%s" % fullpath
+                    print("\t%s" % fullpath)
                     self.loadExpFile(fullpath)
             dlg.Destroy()
         except Exception as e:
             transit_tools.transit_message("Error: %s" % e)
-            print "PATH", fullpath
+            print("PATH", fullpath)
             exc_type, exc_obj, exc_tb = sys.exc_info()
             fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
             print(exc_type, fname, exc_tb.tb_lineno)
@@ -1728,7 +1715,7 @@ along with TRANSIT.  If not, see <http://www.gnu.org/licenses/>.
                transit_tools.ShowError(MSG="Need to select a 'Resampling' results file for this type of plot.")
 
         except Exception as e:
-            print "Error occurred creating plot:", str(e)
+            print("Error occurred creating plot:", str(e))
 
 #
 
@@ -1755,7 +1742,7 @@ along with TRANSIT.  If not, see <http://www.gnu.org/licenses/>.
             plt.show()
 
         except Exception as e:
-            print "Error occurred creating plot:", str(e)
+            print("Error occurred creating plot:", str(e))
 
 #
 
@@ -1800,9 +1787,9 @@ along with TRANSIT.  If not, see <http://www.gnu.org/licenses/>.
                 )
             if dlg.ShowModal() == wx.ID_OK:
                 paths = dlg.GetPaths()
-                print "You chose the following Results file(s):"
+                print("You chose the following Results file(s):")
                 for fullpath in paths:
-                    print "\t%s" % fullpath
+                    print("\t%s" % fullpath)
                     name = transit_tools.basename(fullpath)
                     line = open(fullpath).readline()
                     if line.startswith("#Gumbel"):
@@ -1828,7 +1815,7 @@ along with TRANSIT.  If not, see <http://www.gnu.org/licenses/>.
             dlg.Destroy()
         except Exception as e:
             transit_tools.transit_message("Error: %s" %  e)
-            print "PATH", fullpath
+            print("PATH", fullpath)
             exc_type, exc_obj, exc_tb = sys.exc_info()
             fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
             print(exc_type, fname, exc_tb.tb_lineno)
